itkwasm.interface_types - itkwasm python documentation
Description: Module Contents: Classes:,, InterfaceTypes,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.interface_types`

## Module Contents

### Classes

`InterfaceTypes` |

### API

class itkwasm.interface_types.InterfaceTypes

  Bases: `enum.Enum`

  TextFile

    ‘InterfaceTextFile’

  BinaryFile

    ‘InterfaceBinaryFile’

  TextStream

    ‘InterfaceTextStream’

  BinaryStream

    ‘InterfaceBinaryStream’

  Image

    ‘InterfaceImage’

  Mesh

    ‘InterfaceMesh’

  PolyData

    ‘InterfacePolyData’